import { __ } from '@wordpress/i18n';
import { RichText, MediaUpload, useBlockProps, InspectorControls, ColorPalette, MediaUploadCheck } from '@wordpress/block-editor';
import { Button, Panel, PanelBody, PanelRow, SelectControl, ResponsiveWrapper, __experimentalNumberControl as NumberControl, __experimentalBoxControl as BoxControl, __experimentalUnitControl as UnitControl, __experimentalGradientPicker as GradientPicker } from '@wordpress/components';
import '../style.css';
import { useState } from '@wordpress/element';
import Slider from "react-slick";

const Edit = (props) => {
	const {
		attributes: { title, receipenamecolor, mediaURL, mediaID, ingredients, subtitlecolor, subcontentcolor, instructions, imagestyle, receipe_category, preptime, cooktime, additional, totaltime, servings, datayield, nutrition_facts, message, bordercolor, blockcolor, border_style, borderradiousvalue, paddingleft, paddingtop, paddingright, paddingbottom, colorValue, images },
		setAttributes,
	} = props;

	const blockProps = useBlockProps();

	const ALLOWED_MEDIA_TYPES = ['image'];

	function MyMediaUploader({ mediaIDs, onSelect }) {
		return (
			<MediaUploadCheck>
				<MediaUpload
					onSelect={onSelect}
					allowedTypes={ALLOWED_MEDIA_TYPES}
					value={mediaIDs}
					render={({ open }) => (
						<Button
							onClick={open}
							className="button button-large"
						>{mediaIDs.length < 1 ? 'Upload/Select Images' : 'Add/Remove Image'}</Button>
					)}
					gallery
					multiple
				/>
			</MediaUploadCheck>
		);
	}

	const settings = {
		dots: true,
		infinite: true,
		speed: 500,
		slidesToShow: 1,
		slidesToScroll: 1
	};

	const ImageChangeHandler = (event) => {
		setAttributes({ images: event });
	};

	const onChangeTitle = (value) => {
		setAttributes({ title: value });
	};

	const onChangeTitleColor = (value) => {
		setAttributes({ receipenamecolor: value });
	};

	const onChangeBorderColor = (value) => {
		setAttributes({ bordercolor: value });
	}

	const onChangeBlockColor = (value) => {
		setAttributes({ blockcolor: value });
	}

	const onChangeBorderStyle = (value) => {
		setAttributes({ border_style: value });
	}

	const setborderradious = (value) => {
		setAttributes({ borderradiousvalue: value });
	}

	const setPaddingleftvalue = (value) => {
		setAttributes({ paddingleft: value });
	}	

	const setPaddingtopvalue = (value) => {
		setAttributes({ paddingtop: value });
	}

	const setPaddingrightvalue = (value) => {
		setAttributes({ paddingright: value });
	}

	const setPaddingbottomvalue = (value) => {
		setAttributes({ paddingbottom: value });
	}

	const setcolorValue = (value) => {
		setAttributes({ colorValue: value });
	}
	
	const onChangeIngredients = (value) => {
		console.log(value);
		setAttributes({ ingredients: value });
	};

	const onChangesubtitlecolorColor = (value) => {
		setAttributes({ subtitlecolor: value });
	};

	const onChangesubcontentColor = (value) => {
		setAttributes({ subcontentcolor: value });
	};

	const onChangeInstructions = (value) => {
		setAttributes({ instructions: value });
	};

	const onChangeImageStyles = (value) => {
		setAttributes({ imagestyle: value });
	};

	const get_receipe_category = (value) => {
		setAttributes({ receipe_category: value });
	};

	const get_preptime = (value) => {
		setAttributes({ preptime: value });
	};

	const get_cooktime = (value) => {
		setAttributes({ cooktime: value });
	};

	const get_additional = (value) => {
		setAttributes({ additional: value });
	};

	const get_totaltime = (value) => {
		setAttributes({ totaltime: value });
	};

	const get_servings = (value) => {
		setAttributes({ servings: value });
	};

	const get_datayield = (value) => {
		setAttributes({ datayield: value });
	};

	const get_nutrition_facts = (value) => {
		setAttributes({ nutrition_facts: value });
	};

	const get_message = (value) => {
		setAttributes({ message: value });
	};



	return (

		<div {...blockProps} >
			<InspectorControls>
				

				<PanelBody title={__('Border & Block Settings')} initialOpen={false}>
					<p>Border Color: </p>
					<ColorPalette value={bordercolor} onChange={onChangeBorderColor} />

					<p>Border Radius</p>
					<UnitControl
						onChange={setborderradious}
						value={borderradiousvalue}
					/>
					<br />
					<p>Block Color: </p>
					<ColorPalette value={blockcolor} onChange={onChangeBlockColor} />
					<br />
					<p>Border Style: </p>
					<SelectControl
						value={border_style}
						options={[
							{ label: __('Dotted'), value: __('dotted') },
							{ label: __('Dashed'), value: __('dashed') },
							{ label: __('Solid'), value: __('solid') },
							{ label: __('Double'), value: __('double') },
							{ label: __('Groove'), value: __('groove') },
							{ label: __('Ridge'), value: __('ridge') },
							{ label: __('Insert'), value: __('inset') },
							{ label: __('Outset'), value: __('outset') },
							{ label: __('None'), value: __('none') },
							{ label: __('Hidden'), value: __('hidden') },
							{ label: __('Main Dishes'), value: __('Main Dishes') },
						]}
						onChange={onChangeBorderStyle}
					/>

				</PanelBody>

				<PanelBody title={__('Padding Settings')} initialOpen={false}>

					<p>Padding Type:<sup> Top,Right,Bottom,Left </sup> </p>
					<div className='Paddingparent'>
						<div></div>
						<UnitControl className="paddingfield" onChange={setPaddingtopvalue} value={paddingtop} />
						<UnitControl className="paddingfield" onChange={setPaddingrightvalue} value={paddingright} />
						<UnitControl className="paddingfield" onChange={setPaddingbottomvalue} value={paddingbottom} />
						<UnitControl className="paddingfield" onChange={setPaddingleftvalue} value={paddingleft} />
					</div>

				</PanelBody>


				<PanelBody title={__('Color Settings')} initialOpen={false}>
					<p>Title Color: </p>
					<ColorPalette value={receipenamecolor} onChange={onChangeTitleColor} />
					<p>Sub-Title Title Color: </p>
					<ColorPalette value={subtitlecolor} onChange={onChangesubtitlecolorColor} />
					<p>Sub-Content Text Color: </p>
					<ColorPalette value={subcontentcolor} onChange={onChangesubcontentColor} />
					<br /><br /><p>Background Color: </p>
					<GradientPicker
						value={colorValue}
						onChange={setcolorValue}
					/>


				</PanelBody>

				<PanelBody title={__('Image Settings')} initialOpen={false}>
					<p><strong>Image Styles: </strong></p>
					<SelectControl
						value={imagestyle}
						options={[
							{ label: __('Rounded'), value: __('img-rounded') },
							{ label: __('Circle'), value: __('img-circle') },
							{ label: __('Thumbnail'), value: __('img-thumbnail') },
							{ label: __('Responsive'), value: __('img-responsive') },
						]}
						onChange={onChangeImageStyles}
					/>


				</PanelBody>

				<PanelBody title={__('Receipe Category')} initialOpen={false}>
					<SelectControl
						value={receipe_category}
						options={[
							{ label: __('Appetizers and Snacks'), value: __('Appetizers and Snacks') },
							{ label: __('Bread Recipes'), value: __('Bread Recipes') },
							{ label: __('Breakfast and Brunch'), value: __('Breakfast and Brunch') },
							{ label: __('Desserts'), value: __('Desserts') },
							{ label: __('Dinner Recipes'), value: __('Dinner Recipes') },
							{ label: __('Drinks'), value: __('Drinks') },
							{ label: __('Everyday Cooking'), value: __('Everyday Cooking') },
							{ label: __('Holidays and Events'), value: __('Holidays and Events') },
							{ label: __('Seafood Recipes'), value: __('Seafood Recipes') },
							{ label: __('Salad Recipes'), value: __('Salad Recipes') },
							{ label: __('Pasta and Noodles'), value: __('Pasta and Noodles') },
							{ label: __('Main Dishes'), value: __('Main Dishes') },
						]}
						onChange={get_receipe_category}
					/>
				</PanelBody>
			</InspectorControls>
			<div className="recepe-card" style={{ borderStyle: border_style, borderColor: bordercolor, background: blockcolor, borderRadius: borderradiousvalue, paddingTop: paddingtop, paddingRight: paddingright, paddingBottom: paddingbottom, paddingLeft: paddingleft, background: colorValue }}>
				<RichText
					tagName='h2'
					style={{ color: receipenamecolor }}
					placeholder={__('Write Recipe title…')}
					value={title}
					onChange={onChangeTitle}
				/>
				
				<div>
					<Slider {...settings}>
						{
							images.length >= 1 ?
								images.map((item, index) =>
								(
									<div className='block'>

										<img className={imagestyle}  src={item.url} width={item.width} />

									</div>
								)) : <p>Click the button and add some images to your Recipe Block</p>
						}
					</Slider>
				</div>
				<MyMediaUploader
					mediaIDs={images.map(item => item.id)}
					onSelect={ImageChangeHandler}
				/>
				<RichText
					tagName='p'
					placeholder={__('10 mins')}
					style={{ color: subcontentcolor }}
					value={preptime}
					onChange={get_preptime}
				/>

				<RichText
					tagName='p'
					placeholder={__('50 mins')}
					style={{ color: subcontentcolor }}
					value={cooktime}
					onChange={get_cooktime}
				/>

				<RichText
					tagName='p'
					placeholder={__('1 hr 10 mins')}
					style={{ color: subcontentcolor }}
					value={additional}
					onChange={get_additional}
				/>

				<RichText
					tagName='p'
					placeholder={__('2 hrs 10 mins')}
					style={{ color: subcontentcolor }}
					value={totaltime}
					onChange={get_totaltime}
				/>

				<RichText
					tagName='p'
					placeholder={__('4')}
					style={{ color: subcontentcolor }}
					value={servings}
					onChange={get_servings}
				/>

				<RichText
					tagName='p'
					placeholder={__('4 servings')}
					style={{ color: subcontentcolor }}
					value={datayield}
					onChange={get_datayield}
				/>

				<h3 style={{ color: subtitlecolor }}>{__('Ingredients')}</h3>

				<RichText
					tagName='p'
					placeholder={__('Write a list of ingredients…')}
					value={ingredients}
					onChange={onChangeIngredients}
					style={{ color: subcontentcolor }}
					className='ingredients'
				/>

				<h3 style={{ color: subtitlecolor }}>{__('Instructions')}</h3>

				<RichText
					tagName='ul'
					multiline='li'
					placeholder={__('Write the instructions…')}
					style={{ color: subcontentcolor }}
					value={instructions}
					onChange={onChangeInstructions}
				/>

				<h3 style={{ color: subtitlecolor }}>{__('Nutrition Facts')}</h3>

				<RichText
					tagName='p'
					placeholder={__('salt etc..')}
					style={{ color: subcontentcolor }}
					value={nutrition_facts}
					onChange={get_nutrition_facts}
				/>

				<h3 style={{ color: subtitlecolor }}>{__('Steps :')}</h3>

				<RichText
					tagName='ul'
					multiline='li'
					value={message}
					onChange={get_message}
					style={{ color: subcontentcolor }}
				/>

			</div>
		</div>

	);
};

export default Edit;
